from django.urls import path, include, re_path
from django.views.generic.base import RedirectView

urlpatterns = [
    re_path(
        r"^$", RedirectView.as_view(url="apis/doc/", permanent=False), name="api_doc"
    ),
    path("apis/", include("kfsd.apps.endpoints.urls")),
    path("", include("kfsd.apps.frontend.collection.errors")),
]



from setuptools import setup, find_packages

setup(
    name="kfsd",
    version="0.0.218",
    description="Sample App",
    long_description="Sample Pkg",
    long_description_content_type="text/markdown",
    author="Gokul Nathan",
    author_email="nathangokul111@gmail.com",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
)
